==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/TRANSACTIONPROMPTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TRANSACTIONPROMPTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TRANSACTIONPROMPTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONSEQUENCE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TRANSACTIONPROMPTID_Type", propOrder = {
    "transaction",
    "transactiondescription",
    "transactionsequence"
})
public class TRANSACTIONPROMPTID_Type {

    @XmlElement(name = "TRANSACTION", required = true)
    protected String transaction;
    @XmlElement(name = "TRANSACTIONDESCRIPTION")
    protected String transactiondescription;
    @XmlElement(name = "TRANSACTIONSEQUENCE")
    protected long transactionsequence;

    /**
     * Obtient la valeur de la propriété transaction.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRANSACTION() {
        return transaction;
    }

    /**
     * Définit la valeur de la propriété transaction.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRANSACTION(String value) {
        this.transaction = value;
    }

    /**
     * Obtient la valeur de la propriété transactiondescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRANSACTIONDESCRIPTION() {
        return transactiondescription;
    }

    /**
     * Définit la valeur de la propriété transactiondescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRANSACTIONDESCRIPTION(String value) {
        this.transactiondescription = value;
    }

    /**
     * Obtient la valeur de la propriété transactionsequence.
     * 
     */
    public long getTRANSACTIONSEQUENCE() {
        return transactionsequence;
    }

    /**
     * Définit la valeur de la propriété transactionsequence.
     * 
     */
    public void setTRANSACTIONSEQUENCE(long value) {
        this.transactionsequence = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/TRANSACTIONPROMPTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TRANSACTIONPROMPTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TRANSACTIONPROMPTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONSEQUENCE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TRANSACTIONPROMPTID_Type", propOrder = {
    "transaction",
    "transactiondescription",
    "transactionsequence"
})
public class TRANSACTIONPROMPTID_Type {

    @XmlElement(name = "TRANSACTION", required = true)
    protected String transaction;
    @XmlElement(name = "TRANSACTIONDESCRIPTION")
    protected String transactiondescription;
    @XmlElement(name = "TRANSACTIONSEQUENCE")
    protected long transactionsequence;

    /**
     * Gets the value of the transaction property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRANSACTION() {
        return transaction;
    }

    /**
     * Sets the value of the transaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRANSACTION(String value) {
        this.transaction = value;
    }

    /**
     * Gets the value of the transactiondescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRANSACTIONDESCRIPTION() {
        return transactiondescription;
    }

    /**
     * Sets the value of the transactiondescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRANSACTIONDESCRIPTION(String value) {
        this.transactiondescription = value;
    }

    /**
     * Gets the value of the transactionsequence property.
     * 
     */
    public long getTRANSACTIONSEQUENCE() {
        return transactionsequence;
    }

    /**
     * Sets the value of the transactionsequence property.
     * 
     */
    public void setTRANSACTIONSEQUENCE(long value) {
        this.transactionsequence = value;
    }

}
